@@ -16,9 +16,9 @@ DATABASES = {
 SECRET_KEY = '[V$xMycv[(YwhThQD+p[s@Wb@Ygy@:`M%D3I8Fs2tJ^Aw#ac$AJ65".*]uwPaK_'
 
 ALLOWED_HOSTS = [
-    '127.0.0.1',
-    'localhost',
-] + env.list('DOMAINS', default=[])
+                    '127.0.0.1',
+                    'localhost',
+                ] + env.list('DOMAINS', default=[])
 
 INSTALLED_APPS = [
     'snowebsvg',
@@ -31,6 +31,7 @@ INSTALLED_APPS = [
     'django.contrib.staticfiles',
     'django.contrib.sites',
     "django.contrib.sitemaps",
+    'storages',
 ]
 
 MIDDLEWARE = [
@@ -42,6 +43,7 @@ MIDDLEWARE = [
     'django.contrib.messages.middleware.MessageMiddleware',
     'django.middleware.clickjacking.XFrameOptionsMiddleware',
     'django.middleware.gzip.GZipMiddleware',
+    'app.middlewares.ThemeMiddleware',
 ]
 
 
@@ -84,9 +86,30 @@ STATICFILES_FINDERS = [
     'django.contrib.staticfiles.finders.AppDirectoriesFinder',
 ]
 
-STATICFILES_DIRS = [os.path.join(BASE_DIR, 'static')]
+STATICFILES_DIRS = [
+    os.path.join(BASE_DIR, 'static'),
+]
+
 STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')
 STATIC_URL = '/static/'
 
-MEDIA_ROOT = BASE_DIR
-MEDIA_URL = '/'
+# AWS
+
+
+AWS_ACCESS_KEY_ID = env.str('AWS_ACCESS_KEY_ID', None)
+AWS_SECRET_ACCESS_KEY = env.str('AWS_SECRET_ACCESS_KEY', None)
+AWS_S3_REGION_NAME = env.str('AWS_S3_REGION_NAME', None)
+AWS_S3_CUSTOM_DOMAIN = env.str('AWS_S3_CUSTOM_DOMAIN', None)
+AWS_STORAGE_BUCKET_NAME = env.str('AWS_STORAGE_BUCKET_NAME', None)
+AWS_DISTRIBUTION_ID = env.str('AWS_DISTRIBUTION_ID', None)
+
+if AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY:
+    AWS_IS_GZIPPED = True
+    AWS_DEFAULT_ACL = 'public-read'
+    AWS_S3_FILE_OVERWRITE = False
+    DEFAULT_FILE_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
+    AWS_S3_OBJECT_PARAMETERS = {
+        'CacheControl': 'public, max-age=31536000',
+    }
+    STATIC_URL = 'https://%s/' % AWS_S3_CUSTOM_DOMAIN
+    STATICFILES_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
